Field

Trait Field 

pub trait Field {
    type Elem: ?Sized;

    const RANK: Option<usize> = None;

    // Required methods
    fn kind(&self) -> Fields;
    fn rank(&self) -> usize;
    fn size(&self) -> usize;
}
A field is a set of elements with two binary operations, addition and multiplication, that satisfy the following axioms:

  • Associativity of addition and multiplication
  • Commutativity of addition and multiplication

Provided Associated Constants

const RANK: Option<usize> = None

Required Associated Types

Required Methods

fn kind(&self) -> Fields

fn rank(&self) -> usize

The rank of the field; i.e the number of dimensions.

fn size(&self) -> usize

The number of elements in the field.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors